# Installation

These instructions are for Ubuntu 16.04 or later. 

DelegatorBot Uses MySQL. In short, to install execute these commands.

```
    sudo apt-get update
    sudo apt-get install mysql-server
    mysql_secure_installation

```

For a more detailed set of instructions please read [How To Install MySQL on Ubuntu 16.04](https://www.digitalocean.com/community/tutorials/how-to-install-mysql-on-ubuntu-16-04)

Running the bot for the first time will create all necessary tables.

To install Delegator bot:


`pip3 install delegatorbot`
`sudo -H pip3 install delegatorbot`


